<?php

use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Field\Enums\FieldType;

return [
    [
        'label' => 'Key details',
        'component' => FieldType::Section()->getValue(),
        'children' => [
            [
                'component' => FieldType::TextInput()->getValue(),
                'name' => 'name',
                'label' => 'Event name',
                'classes' => ['col-6'],
                'validation' => [
                    'required',
                ],
                'placeholder' => 'E.g. Congress meeting',
            ],
            [
                'component' => FieldType::TextInput()->getValue(),
                'name' => 'url',
                'label' => 'Url',
                'classes' => ['col-6'],
                'validation' => [
                    'required',
                ],
                'placeholder' => 'congressmeeting12',
            ],
            [
                'component' => FieldType::Select()->getValue(),
                'name' => 'type',
                'label' => 'Event Type',
                'classes' => ['col-6'],
                'placeholder' => 'Select a event component',
                'options' => [
                    Option::make('Single'),
                    Option::make('Seminar'),
                ],
                'validation' => [
                    'required',
                ],
            ],
            [
                'component' => FieldType::Select()->getValue(),
                'name' => 'registration_type',
                'label' => 'Registration Type',
                'classes' => ['col-6'],
                'placeholder' => 'Select a registration component',
                'options' => [
                    Option::make('Open'),
                    Option::make('Closed'),
                ],
            ],
            [
                'component' => FieldType::TextInput()->getValue(),
                'name' => 'capacity',
                'label' => 'Capacity',
                'placeholder' => 'E.g. 150',
                'classes' => ['col-6'],
            ],
            [
                'component' => FieldType::RadioButtons()->getValue(),
                'name' => 'require_approval',
                'label' => 'Does your event require approval?',
                'classes' => ['col-6'],
                'options' => [
                    Option::make('Yes')->value(true),
                    Option::make('No')->value(false),
                ],
            ],
        ],
    ],
    [
        'component' => FieldType::Section()->getValue(),
        'label' => 'Your team',
        'children' => [
            [
                'component' => FieldType::Select()->getValue(),
                'name' => 'line_manager_id',
                'label' => 'Assign a line manager',
                'classes' => ['col-6'],
                'placeholder' => 'Select a line manager',
                'options' => [
                    Option::make('Toby')->value(1),
                    Option::make('Andy')->value(2),
                ],
            ],
            [
                'component' => FieldType::Select()->getValue(),
                'name' => 'team_id',
                'label' => 'Assign a team',
                'classes' => ['col-6'],
                'placeholder' => 'Select a team',
                'options' => [
                    Option::make('Team One')->value(1),
                    Option::make('Team Two')->value(2),
                ],
            ],
            [
                'component' => FieldType::Select()->getValue(),
                'name' => 'coordinator_id',
                'label' => 'Assign a meeting co-oordinator',
                'classes' => ['col-6'],
                'placeholder' => 'Select a meeting co-ordinator',
                'options' => [
                    Option::make('Fadhil')->value(1),
                    Option::make('Dan')->value(2),
                ],
            ],
        ],
    ],
    [
        'label' => 'Contact details',
        'component' => FieldType::Section()->getValue(),
        'children' => [
            [
                'component' => FieldType::TextInput()->getValue(),
                'name' => 'contact_phone',
                'label' => 'Contact phone',
                'placeholder' => 'E.g. 01010 023 445',
            ],
            [
                'component' => FieldType::TextInput()->getValue(),
                'name' => 'contact_email',
                'label' => 'Contact email',
                'placeholder' => 'E.g. email@example.com',
                'validation' => [
                    'nullable',
                    'email',
                ],
            ],
        ],
    ],
    [
        'label' => 'Status',
        'component' => FieldType::Section()->getValue(),
        'hideWhen' => [
            'create',
        ],
        'children' => [
            [
                'component' => FieldType::Select()->getValue(),
                'name' => 'status',
                'label' => 'Event Status',
                'classes' => ['col-6'],
                'options' => [
                    Option::make('Draft'),
                    Option::make('Published'),
                    Option::make('Archived'),
                ],
                'validation' => [],
                'updateValidation' => [
                    'required',
                ],
                'placeholder' => 'Please select event status',
                'defaultValue' => Option::make('Draft'),
            ],
        ],
    ],
];
