<?php

namespace EventPortal\Domain\Component\Concerns;

trait HasOptions
{
    /** @var array<Option> */
    public $options = [];

    public function hasOptions(): bool
    {
        return true;
    }

    public function options(?array $options): self
    {
        $this->options = $this->convertToArray($options);

        return $this;
    }

    public function toArray(): array
    {
        return array_merge(parent::toArray(), [
            'value' => $this->value,
            'options' => $this->options,
        ]);
    }

    /**
     * Map array of Option into plain multi-dimensional array.
     */
    private function convertToArray(array $options): array
    {
        return collect($options)->map(function ($options): array {
            if (is_array($options)) {
                return $options;
            }

            return $options->toArray();
        })
        ->toArray();
    }
}
