<?php

namespace EventPortal\Domain\Form;

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Value;
use Illuminate\Support\Arr;

class Form
{
    /** @var string|\EventPortal\Contracts\HasFields */
    protected $model;

    /** @var array */
    public $content = [];

    /** @var array */
    public $actions = [];

    /**
     * @param string|\EventPortal\Contracts\HasFields $model
     */
    public function model($model): self
    {
        $this->model = $model;

        return $this;
    }

    public function addAction(callable $callable): self
    {
        $this->actions[] = $callable() instanceof Button ? $callable()->toArray() : $callable();

        return $this;
    }

    public function addSections(array $sections): self
    {
        $this->content = $sections;

        return $this;
    }

    public function hasInstanceOfModel(): bool
    {
        return is_string($this->model) === false;
    }

    /**
     * @return \EventPortal\Contracts\HasFields|string
     */
    public function getModel()
    {
        return $this->model;
    }

    /**
     * @return mixed|string
     */
    public function getValue(string $field)
    {
        $field = collect($this->content)
            ->pluck('children')
            ->flatten(1)
            ->firstWhere('name', $field);

        return Value::get(Arr::get($field, 'value'));
    }
}
