<?php

namespace EventPortal\Providers;

use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Arr;
use Illuminate\Support\ServiceProvider;
use Inertia\Inertia;

class AppServiceProvider extends ServiceProvider
{
    private const CONFIGS = [
        'defaults.event.fields' => '/defaults/event/fields.php',
        'defaults.event.tableColumns' => '/defaults/event/tableColumns.php',
        'defaults.user.fields' => '/defaults/user/fields.php',
        'defaults.user.tableColumns' => '/defaults/user/tableColumns.php',
        'defaults.delegate.fields' => '/defaults/delegate/fields.php',
        'defaults.delegate.tableColumns' => '/defaults/delegate/tableColumns.php',
    ];

    /** @var string */
    protected $root = __DIR__.'/../..';

    public function boot(): void
    {
        $this->app->booted(function (): void {
            $this->loadRoutesFrom("{$this->root}/routes/routes.php");
        });

        $this->loadViewsFrom("{$this->root}/resources/views", 'EventPortal');
        
        $this->loadMigrationsFrom("{$this->root}/database/migrations");
        
        $this->loadFactoriesFrom("{$this->root}/database/factories");

        foreach (self::CONFIGS as $key => $path) {
            $fullPath = $this->root.'/config' . $path;
            $this->publishes([
                $fullPath => config_path($path),
            ], 'defaults');
            
            $this->mergeConfigFrom($fullPath, $key);
        }
        
        $this->app->bind(\Illuminate\Contracts\Debug\ExceptionHandler::class, \EventPortal\Exceptions\Handler::class);

        Inertia::setRootView('EventPortal::app');

        Inertia::share([
            'errors' => function () {
                return session('errors') ? session('errors')->getBag('default')->getMessages() : (object) [];
            },
        ]);

        JsonResource::withoutWrapping();
    }

    /**
     * @param string $path
     * @param string $key
     * @phpcsSuppress SlevomatCodingStandard.TypeHints.ParameterTypeHint.MissingNativeTypeHint
     */
    protected function mergeConfigFrom($path, $key): void
    {
        $config = $this->app['config']->get($key, []);

        $this->app['config']->set($key, $this->mergeConfig(require $path, $config));
    }

    /**
     * Allows configs that are nested with or without keys to be merged
     */
    private function mergeConfig(array $original, array $merging): array
    {
        $array = array_replace($original, $merging);

        foreach ($original as $key => $value) {
            if (!is_array($value)) {
                continue;
            }

            if (!Arr::exists($merging, $key)) {
                continue;
            }

            if (is_numeric($key)) {
                continue;
            }

            $array[$key] = $this->mergeConfig($value, $merging[$key]);
        }

        return $array;
    }
}
