<?php

namespace EventPortal\Tests\Feature\Actions;

use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Field\Enums\FieldType;
use EventPortal\Domain\Field\Actions\InitialiseFields;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class InitialiseFieldsTest extends TestCase
{
    use DatabaseMigrations;

    private function getData(): array
    {
        return  [
            'type' => Event::class,
            'label' => 'Event',
            'content' => [
                [
                    'label' => 'Key details',
                    'component' => FieldType::Section()->getValue(),
                    'children' => [
                        [
                            'label' => 'Event name',
                            'name' => 'name',
                            'component' => FieldType::TextInput()->getValue(),
                        ],
                        [
                            'label' => 'Event type',
                            'name' => 'type',
                            'component' => FieldType::Select()->getValue(),
                            'options' => [
                                Option::make('Single'),
                                Option::make('Seminar'),
                            ],
                        ],
                    ]
                ],
            ],
        ];
    }

    /** @test **/
    public function can_add_initial_fields_for_model()
    {
        /** @var InitialiseFields $action */
        $action = new InitialiseFields;

        $event = factory(Event::class)->create();

        $action->execute($this->getData()['content'], $event);

        $section = Field::first();

        $this
            ->assertDatabaseHas('events', [
                'id' => $event->id,
            ])
            ->assertDatabaseHas('fields', [
                'model_id' => $event->id,
                'model_type' => Event::class,
                'label' => 'Key details',
                'type' => 'Section',
            ])
            ->assertDatabaseHas('fields', [
                'model_id' => $event->id,
                'model_type' => Event::class,
                'section_id' => $section->id,
                'type' => 'TextInput',
                'label' => 'Event name',
                'name' => 'name',
            ])
            ->assertDatabaseHas('fields', [
                'model_id' => $event->id,
                'model_type' => Event::class,
                'section_id' => $section->id,
                'type' => 'Select',
                'label' => 'Event type',
                'name' => 'type',
            ]);
    }

    /** @test **/
    public function adds_initial_response_if_present()
    {
        $data = [
            'type' => Event::class,
            'label' => 'Event',
            'content' => [
                [
                    'label' => 'Key details',
                    'component' => FieldType::Section()->getValue(),
                    'children' => [
                        [
                            'label' => 'Event name',
                            'name' => 'name',
                            'component' => FieldType::TextInput()->getValue(),
                            'value' => 'Hello World!'
                        ],
                        [
                            'label' => 'Event type',
                            'name' => 'type',
                            'component' => FieldType::Select()->getValue(),
                            'options' => [
                                Option::make('Single'),
                                Option::make('Seminar'),
                            ],
                            'value' => Option::make('Single'),
                        ],
                    ]
                ],
            ],
        ];

        $action = new InitialiseFields;

        $event = factory(Event::class)->create();

        $action->execute($data['content'], $event);


        $fieldA = Field::where('name', 'name')->first();
        $fieldB = Field::where('name', 'type')->first();

        $this
            ->assertFieldHasResponse($fieldA, 'Hello World!')
            ->assertFieldHasResponse($fieldB, ['label' => 'Single', 'value' => 'single']);
    }
}
