<?php

namespace EventPortal\Tests\Unit\Component;

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Enums\InertiaMethod;
use EventPortal\Tests\TestCase;
use Spatie\Snapshots\MatchesSnapshots;

class ButtonTest extends TestCase
{
    use MatchesSnapshots;

    /** @test **/
    public function can_make()
    {
        $button = Button::make('Cancel');

        $this->assertEquals('Cancel', $button->label);
    }

    /** @test **/
    public function can_add_method()
    {
        $button = Button::make('Cancel')->method(InertiaMethod::VISIT());

        $this->assertEquals('VISIT', $button->method);
    }

    /** @test **/
    public function can_add_route()
    {
        $button = Button::make('Cancel')->route('admin.event.index');

        $this->assertEquals('admin.event.index', $button->route);
    }

    /** @test **/
    public function can_add_route_parameters()
    {
        $button = Button::make('Cancel')->route('admin.event.update', ['event' => 1]);

        $this->assertEquals(['event' => 1], $button->routeParameters);
    }

    /** @test **/
    public function can_add_route_parameters_that_is_model()
    {
        $event = factory(Event::class)->make(['id' => 1]);

        $button = Button::make('Cancel')->route('admin.event.update', ['event' => $event]);

        $this->assertEquals(['event' => 1], $button->routeParameters);
    }

    /** @test **/
    public function can_add_multiple_route_parameters()
    {
        $event = factory(Event::class)->make(['id' => 1]);

        $button = Button::make('Cancel')->route('admin.event.update', ['event' => $event, 'form' => 2]);

        $this->assertEquals(['event' => 1, 'form' => 2], $button->routeParameters);
    }

    /** @test **/
    public function can_add_class_names_as_string()
    {
        $button = Button::make('Cancel')->classes('primary');

        $this->assertEquals(['primary'], $button->classes);
    }

    /** @test **/
    public function can_add_class_names_as_array()
    {
        $button = Button::make('Cancel')->classes(['primary', 'danger', 'text-large']);

        $this->assertEquals(['primary', 'danger', 'text-large'], $button->classes);
    }

    /** @test **/
    public function can_add_variant()
    {
        $button = Button::make('Cancel')->variant('secondary');

        $this->assertEquals('secondary', $button->variant);
    }

    /** @test **/
    public function can_get_as_array()
    {
        $event = factory(Event::class)->make(['id' => 1]);

        $button = Button::make('Update Event')
            ->method(InertiaMethod::POST())
            ->route('admin.event.update', ['event' => $event, 'form' => 2])
            ->classes(['primary', 'danger', 'text-large'])
            ->variant('secondary')
            ->toArray();

        $this->assertMatchesJsonSnapshot($button);
    }
}
